#!/usr/bin/env python
# ----------------------------------------------------------------------
#
# Brad T. Aagaard, U.S. Geological Survey
# Charles A. Williams, GNS Science
# Matthew G. Knepley, University of Chicago
#
# This code was developed as part of the Computational Infrastructure
# for Geodynamics (http://geodynamics.org).
#
# Copyright (c) 2010-2014 University of California, Davis
#
# See COPYING for license information.
#
# ----------------------------------------------------------------------
#
# PREREQUISITES: numpy

# ======================================================================
import numpy

# Define parameters.
interfaceFile = "interface_points.txt"
numContours = 4
pointsPerContour = 3
journalFile = "interface_netsurf.jou"
acisFile = "interface_surf.sat"

# Journal file formatting, etc.
separator = "# ----------------------------------------------------------\n"
journalBeg = \
           "# CUBIT journal file generated by interface_netsurf.py.\n" + \
           "#\n" + \
           "# Create an ACIS NURBS surface from intersecting lines.\n" + \
           "#\n" + separator + \
           "reset\n"
lineBeg = "create curve spline"
splineFmt = " location %10.2e %10.2e %10.2e"
netFmt = "create surface net u curve %d to %d v curve %d to %d\n"
delCmd = "delete curve all\n"
expCmd = "export Acis '" + acisFile + "'\n"


# Read coordinates and reshape them.
intCoords = numpy.loadtxt(interfaceFile, dtype=numpy.float64).reshape(numContours, pointsPerContour, 3)

j = open(journalFile, 'w')
j.write(journalBeg)

# Loop over contours (u-lines).
for contour in range(numContours):
    points = intCoords[contour,:,:]
    j.write(lineBeg)
    for pointNum in range(pointsPerContour):
        point = points[pointNum,:]
        j.write(splineFmt % (point[0], point[1], point[2]))

    j.write("\n")

# Loop over profiles (v-lines).
for profile in range(pointsPerContour):
    points = intCoords[:,profile,:]
    j.write(lineBeg)
    for pointNum in range(numContours):
        point = points[pointNum,:]
        j.write(splineFmt % (point[0], point[1], point[2]))

    j.write("\n")

# Create net surface.
uline1 = 1
uline2 = numContours
vline1 = numContours + 1
vline2 = vline1 + pointsPerContour - 1
j.write(netFmt % (uline1, uline2, vline1, vline2))

# Delete spline curves and export Acis file.
j.write(delCmd)
j.write(expCmd)
j.close()

# End of file
