#!/usr/bin/env python
# ----------------------------------------------------------------------
#
# Brad T. Aagaard, U.S. Geological Survey
# Charles A. Williams, GNS Science
# Matthew G. Knepley, University of Chicago
#
# This code was developed as part of the Computational Infrastructure
# for Geodynamics (http://geodynamics.org).
#
# Copyright (c) 2010-2014 University of California, Davis
#
# See COPYING for license information.
#
# ----------------------------------------------------------------------
#
# PREREQUISITES: numpy

# ======================================================================
import numpy

# Define parameters.
demFile = "topobath_points.txt"
numProfiles = 4
pointsPerProfile = 3
journalFile = "topobath_netsurf.jou"
acisFile = "topobath_surf.sat"

# Journal file formatting, etc.
separator = "# ----------------------------------------------------------\n"
journalBeg = \
           "# CUBIT journal file generated by topobath_netsurf.py.\n" + \
           "#\n" + \
           "# Create an ACIS NURBS surface from intersecting lines.\n" + \
           "#\n" + separator + \
           "reset\n"
lineBeg = "create curve spline"
splineFmt = " location %10.2e %10.2e %10.2e"
netFmt = "create surface net u curve %d to %d v curve %d to %d\n"
delCmd = "delete curve all\n"
expCmd = "export Acis '" + acisFile + "'\n"


# Read coordinates and reshape them.
demCoords = numpy.loadtxt(demFile, dtype=numpy.float64).reshape(numProfiles, pointsPerProfile, 3)

j = open(journalFile, 'w')
j.write(journalBeg)

# Loop over profiles (u-lines).
for profile in range(numProfiles):
    points = demCoords[profile,:,:]
    j.write(lineBeg)
    for pointNum in range(pointsPerProfile):
        point = points[pointNum,:]
        j.write(splineFmt % (point[0], point[1], point[2]))

    j.write("\n")

# Loop over contours (v-lines).
for contour in range(pointsPerProfile):
    points = demCoords[:,contour,:]
    j.write(lineBeg)
    for pointNum in range(numProfiles):
        point = points[pointNum,:]
        j.write(splineFmt % (point[0], point[1], point[2]))

    j.write("\n")

# Create net surface.
uline1 = 1
uline2 = numProfiles
vline1 = numProfiles + 1
vline2 = vline1 + pointsPerProfile - 1
j.write(netFmt % (uline1, uline2, vline1, vline2))

# Delete spline curves and export Acis file.
j.write(delCmd)
j.write(expCmd)
j.close()

# End of file
